/*
 * Bibliothek - DockingFrames
 * Library built on Java/Swing, allows the user to "drag and drop"
 * panels containing any Swing-Component the developer likes to add.
 * 
 * Copyright (C) 2007 Benjamin Sigg
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 * 
 * Benjamin Sigg
 * benjamin_sigg@gmx.ch
 * CH - Switzerland
 */
package bibliothek.gui.dock.common.location;

import bibliothek.gui.dock.common.CLocation;
import bibliothek.gui.dock.layout.DockableProperty;
import bibliothek.gui.dock.station.stack.StackDockProperty;

/**
 * A location which can be parent of a stack (stack is also known as tabbed-pane).
 * @author Benjamin Sigg
 *
 */
public abstract class AbstractStackholdingLocation extends CLocation{
	/**
	 * Creates a new stack inside this location.
	 * @param index the tab the new location represents
	 * @return a tab on a stack
	 */
	public CStackLocation stack( int index ){
		return new CStackLocation( this, index );
	}
	
	/**
	 * Creates a new stack inside this location.
	 * @return the tab at the very end of a stack
	 */
	public CStackLocation stack(){
		return new CStackLocation( this );
	}
	
	@Override
	public CLocation expandProperty( DockableProperty property ) {
	    if( property instanceof StackDockProperty ){
	        StackDockProperty stack = (StackDockProperty)property;
	        CStackLocation location = stack( stack.getIndex() );
	        DockableProperty successor = property.getSuccessor();
	        if( successor == null )
	            return location;
	        else
	            return location.expandProperty( successor );
	    }
	    return null;
	}
}
